#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-rename-plugin-2.3.0.0-GW94eAkjgJaEmSgsY8gR5p
key:                  hls-rename-plugin-2.3.0.0-GW94eAkjgJaEmSgsY8gR5p
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f34ba14dfdabf571836b53a06d46b97e
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.3.0.0-GW94eAkjgJaEmSgsY8gR5p
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF
    ghc-9.6.6 ghc-exactprint-1.7.1.0-KZjF9k8x5izE6x14pLdxSE
    ghcide-2.3.0.0-DP33bsJ36IX7rkKn0pOmSo
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-KU0J8Xnn0al9iJMF7TDNCh
    hls-plugin-api-2.3.0.0-eIOi4QsIzsGiCY1Gu0E7W
    hls-refactor-plugin-2.3.0.0-IahytADhLBKCPCj3zzri66
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
    lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4
    mod-0.2.2.0-AefbwLDh7fWILgoxoA2H63 mtl-2.3.1
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

